==> nextcloud-13.0.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/settings/l10n/hr.js <==
OC.L10N.register(
    "settings",
    {
    "Wrong password" : "Pogrešna lozinka",
    "Saved" : "Spremljeno",
    "No user supplied" : "Nijedan korisnik nije dostavljen",
    "Unable to change password" : "Promjena lozinke nije moguća",
    "Authentication error" : "Pogrešna autentikacija",
    "Wrong admin recovery password. Please check the password and try again." : "Pogrešna admin lozinka za oporavak. Molimo provjerite lozinku i pokušajte ponovno.",
    "You need to set your user email before being able to send test emails." : "Prije nego li ste u mogućnosti slati testnu e-poštu trebate postaviti svoj korisnički email.",
    "Unable to change full name" : "Puno ime nije moguće promijeniti.",
    "Your full name has been changed." : "Vaše puno ime je promijenjeno.",
    "Email saved" : "E-pošta spremljena",
    "Couldn't remove app." : "Nije moguće ukloniti app.",
    "Couldn't update app." : "Ažuriranje aplikacija nije moguće",
    "Email sent" : "E-pošta je poslana",
    "All" : "Sve",
    "Error while disabling app" : "Pogreška pri onemogućavanju app",
    "Disable" : "Onemogućite",
    "Enable" : "Omogućite",
    "Error while enabling app" : "Pogreška pri omogućavanju app",
    "Updated" : "Ažurirano",
    "Valid until {date}" : "Valid until {date}",
    "Delete" : "Izbrišite",
    "Select a profile picture" : "Odaberite sliku profila",
    "Very weak password" : "Lozinka vrlo slaba",
    "Weak password" : "Lozinka slaba",
    "So-so password" : "Lozinka tako-tako",
    "Good password" : "Lozinka dobra",
    "Strong password" : "Lozinka snažna",
    "Groups" : "Grupe",
    "Unable to delete {objName}" : "Nije moguće izbrisati {objName}",
    "A valid group name must be provided" : "Nužno je navesti valjani naziv grupe",
    "deleted {groupName}" : "izbrisana {groupName}",
    "undo" : "poništite",
    "never" : "nikad",
    "deleted {userName}" : "izbrisano {userName}",
    "A valid username must be provided" : "Nužno je navesti valjano korisničko ime",
    "Documentation:" : "Dokumentacija:",
    "Enable only for specific groups" : "Omogućite samo za specifične grupe",
    "Common Name" : "Common Name",
    "Valid until" : "Valid until",
    "Issued By" : "Issued By",
    "Valid until %s" : "Valid until %s",
    "Forum" : "Forum",
    "None" : "Ništa",
    "Login" : "Prijava",
    "Plain" : "Čisti tekst",
    "NT LAN Manager" : "NT LAN Manager",
    "Send mode" : "Način rada za slanje",
    "Encryption" : "Šifriranje",
    "From address" : "S adrese",
    "mail" : "pošta",
    "Authentication method" : "Postupak autentikacije",
    "Authentication required" : "Potrebna autentikacija",
    "Server address" : "Adresa poslužitelja",
    "Port" : "Priključak",
    "Credentials" : "Vjerodajnice",
    "SMTP Username" : "Korisničko ime SMTP",
    "SMTP Password" : "Lozinka SMPT",
    "Test email settings" : "Postavke za testnu e-poštu",
    "Send email" : "Pošaljite e-poštu",
    "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Uzrok tome je vjerojatno neki ubrzivač predmemoriranja kao što je Zend OPcache ilieAccelerator.",
    "System locale can not be set to a one which supports UTF-8." : "Regionalnu shemu sustava nemoguće je postaviti na neku koja podržava UTF-8.",
    "Execute one task with each page loaded" : "Izvršite jedan zadatak sa svakom učitanom stranicom",
    "Version" : "Verzija",
    "Sharing" : "Dijeljenje zajedničkih resursa",
    "Allow apps to use the Share API" : "Dopustite apps korištenje Share API",
    "Allow users to share via link" : "Dopustite korisnicia dijeljenje putem veze",
    "Allow public uploads" : "Dopustite javno učitavanje sadržaja",
    "Enforce password protection" : "Nametnite zaštitu lozinki",
    "Set default expiration date" : "Postavite zadani datum isteka",
    "Expire after " : "Istek nakon",
    "days" : "dana",
    "Enforce expiration date" : "Nametnite datum isteka",
    "Allow resharing" : "Dopustite ponovno dijeljenje zajedničkih resursa",
    "Restrict users to only share with users in their groups" : "Ograničite korisnike na meusobno dijeljenje resursa samo s korisnicima unutar svoje grupe",
    "Exclude groups from sharing" : "Isključite grupe iz dijeljenja zajedničkih resursa",
    "These groups will still be able to receive shares, but not to initiate them." : "Ove će grupe još uvijek moći primati dijeljene resurse, ali ne i inicirati ih",
    "Profile picture" : "Slika profila",
    "Upload new" : "Učitajte novu",
    "Remove image" : "Uklonite sliku",
    "Cancel" : "Odustanite",
    "Email" : "E-pošta",
    "Your email address" : "Vaša adresa e-pošte",
    "Language" : "Jezik",
    "Help translate" : "Pomozite prevesti",
    "Password" : "Lozinka",
    "Current password" : "Trenutna lozinka",
    "New password" : "Nova lozinka",
    "Change password" : "Promijenite lozinku",
    "Username" : "Korisničko ime",
    "Show storage location" : "Prikaži mjesto pohrane",
    "Everyone" : "Svi",
    "Admins" : "Admins",
    "Please enter storage quota (ex: \"512 MB\" or \"12 GB\")" : "Molimo unesite kvotu za spremanje (npr: \"512 MB\" ili \"12 GB\")",
    "Unlimited" : "Neograničeno",
    "Other" : "Ostalo",
    "Quota" : "Kvota",
    "Admin Recovery Password" : "Admin lozinka za oporavak",
    "Enter the recovery password in order to recover the users files during password change" : "Unesite lozinku za oporavak da biste oporavili korisničke datoteke tijekom promjene lozinke",
    "change full name" : "promijenite puno ime",
    "set new password" : "postavite novu lozinku",
    "Default" : "Zadano",
    "Add trusted domain" : "Dodajte pouzdanu domenu",
    "A valid password must be provided" : "Nužno je navesti valjanu lozinku",
    "Create" : "Kreirajte"
},
"nplurals=3; plural=n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2;");

==> nextcloud-13.0.3-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/settings/l10n/hr.js <==
OC.L10N.register(
    "settings",
    {
    "Couldn't remove app." : "Nije moguće ukloniti app.",
    "Couldn't update app." : "Ažuriranje aplikacija nije moguće",
    "Wrong password" : "Pogrešna lozinka",
    "Saved" : "Spremljeno",
    "No user supplied" : "Nijedan korisnik nije dostavljen",
    "Unable to change password" : "Promjena lozinke nije moguća",
    "Authentication error" : "Pogrešna autentikacija",
    "Wrong admin recovery password. Please check the password and try again." : "Pogrešna admin lozinka za oporavak. Molimo provjerite lozinku i pokušajte ponovno.",
    "You need to set your user email before being able to send test emails." : "Prije nego li ste u mogućnosti slati testnu e-poštu trebate postaviti svoj korisnički email.",
    "Unable to change full name" : "Puno ime nije moguće promijeniti.",
    "Email sent" : "E-pošta je poslana",
    "Valid until {date}" : "Valid until {date}",
    "Delete" : "Izbrišite",
    "Select a profile picture" : "Odaberite sliku profila",
    "Very weak password" : "Lozinka vrlo slaba",
    "Weak password" : "Lozinka slaba",
    "So-so password" : "Lozinka tako-tako",
    "Good password" : "Lozinka dobra",
    "Strong password" : "Lozinka snažna",
    "Groups" : "Grupe",
    "Enable" : "Omogućite",
    "Email" : "E-pošta",
    "Unlimited" : "Neograničeno",
    "Error while enabling app" : "Pogreška pri omogućavanju app",
    "Admins" : "Admins",
    "Everyone" : "Svi",
    "Common Name" : "Common Name",
    "Valid until" : "Valid until",
    "Issued By" : "Issued By",
    "Valid until %s" : "Valid until %s",
    "Forum" : "Forum",
    "None" : "Ništa",
    "Login" : "Prijava",
    "Plain" : "Čisti tekst",
    "NT LAN Manager" : "NT LAN Manager",
    "Send mode" : "Način rada za slanje",
    "Encryption" : "Šifriranje",
    "From address" : "S adrese",
    "mail" : "pošta",
    "Authentication method" : "Postupak autentikacije",
    "Authentication required" : "Potrebna autentikacija",
    "Server address" : "Adresa poslužitelja",
    "Port" : "Priključak",
    "Credentials" : "Vjerodajnice",
    "SMTP Username" : "Korisničko ime SMTP",
    "SMTP Password" : "Lozinka SMPT",
    "Test email settings" : "Postavke za testnu e-poštu",
    "Send email" : "Pošaljite e-poštu",
    "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Uzrok tome je vjerojatno neki ubrzivač predmemoriranja kao što je Zend OPcache ilieAccelerator.",
    "System locale can not be set to a one which supports UTF-8." : "Regionalnu shemu sustava nemoguće je postaviti na neku koja podržava UTF-8.",
    "Version" : "Verzija",
    "Execute one task with each page loaded" : "Izvršite jedan zadatak sa svakom učitanom stranicom",
    "Sharing" : "Dijeljenje zajedničkih resursa",
    "Allow apps to use the Share API" : "Dopustite apps korištenje Share API",
    "Allow users to share via link" : "Dopustite korisnicia dijeljenje putem veze",
    "Allow public uploads" : "Dopustite javno učitavanje sadržaja",
    "Enforce password protection" : "Nametnite zaštitu lozinki",
    "Set default expiration date" : "Postavite zadani datum isteka",
    "Expire after " : "Istek nakon",
    "days" : "dana",
    "Enforce expiration date" : "Nametnite datum isteka",
    "Allow resharing" : "Dopustite ponovno dijeljenje zajedničkih resursa",
    "Restrict users to only share with users in their groups" : "Ograničite korisnike na meusobno dijeljenje resursa samo s korisnicima unutar svoje grupe",
    "Exclude groups from sharing" : "Isključite grupe iz dijeljenja zajedničkih resursa",
    "These groups will still be able to receive shares, but not to initiate them." : "Ove će grupe još uvijek moći primati dijeljene resurse, ali ne i inicirati ih",
    "Profile picture" : "Slika profila",
    "Upload new" : "Učitajte novu",
    "Remove image" : "Uklonite sliku",
    "Cancel" : "Odustanite",
    "Your email address" : "Vaša adresa e-pošte",
    "Language" : "Jezik",
    "Help translate" : "Pomozite prevesti",
    "Password" : "Lozinka",
    "Current password" : "Trenutna lozinka",
    "New password" : "Nova lozinka",
    "Change password" : "Promijenite lozinku",
    "Username" : "Korisničko ime",
    "Your full name has been changed." : "Vaše puno ime je promijenjeno.",
    "Email saved" : "E-pošta spremljena",
    "Add trusted domain" : "Dodajte pouzdanu domenu",
    "All" : "Sve",
    "Error while disabling app" : "Pogreška pri onemogućavanju app",
    "Disable" : "Onemogućite",
    "Updated" : "Ažurirano",
    "Unable to delete {objName}" : "Nije moguće izbrisati {objName}",
    "A valid group name must be provided" : "Nužno je navesti valjani naziv grupe",
    "deleted {groupName}" : "izbrisana {groupName}",
    "undo" : "poništite",
    "never" : "nikad",
    "deleted {userName}" : "izbrisano {userName}",
    "A valid username must be provided" : "Nužno je navesti valjano korisničko ime",
    "A valid password must be provided" : "Nužno je navesti valjanu lozinku",
    "Documentation:" : "Dokumentacija:",
    "Enable only for specific groups" : "Omogućite samo za specifične grupe",
    "Show storage location" : "Prikaži mjesto pohrane",
    "Create" : "Kreirajte",
    "Admin Recovery Password" : "Admin lozinka za oporavak",
    "Enter the recovery password in order to recover the users files during password change" : "Unesite lozinku za oporavak da biste oporavili korisničke datoteke tijekom promjene lozinke",
    "Please enter storage quota (ex: \"512 MB\" or \"12 GB\")" : "Molimo unesite kvotu za spremanje (npr: \"512 MB\" ili \"12 GB\")",
    "Other" : "Ostalo",
    "Quota" : "Kvota",
    "change full name" : "promijenite puno ime",
    "set new password" : "postavite novu lozinku",
    "Default" : "Zadano"
},
"nplurals=3; plural=n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2;");
